@@ -7,7 +7,7 @@ warnings.simplefilter("ignore")
 
 from akerbp.mlops.core import logger
 SERVICE_NAME = os.getenv("SERVICE_NAME")
-service = import_module(f"akerbp.mlops.{SERVICE_NAME}.service").service
+service = import_module(f"akerbp.mlops.services.{SERVICE_NAME}").service
 
 logging=logger.get_logger()
 
