@@ -28,6 +28,7 @@ api_keys = dict(
 )
 
 SERVICE_NAME = os.getenv("SERVICE_NAME")
+ENV=os.getenv("ENV")
 
 def set_up_cdf_client(context='run'):
     """
@@ -96,7 +97,7 @@ def create_function(
         logging.debug(f"Deleted function {function_name}")
     except CogniteNotFoundError:
         pass
-    env_vars = dict(SERVICE_NAME=SERVICE_NAME)
+    env_vars = dict(SERVICE_NAME=SERVICE_NAME, ENV=ENV)
     function = client.functions.create( 
         name=function_name, 
         folder=folder, 
@@ -228,7 +229,7 @@ def upload_file(
     external_id, 
     path, 
     metadata={}, 
-    directory='/mlops',
+    directory='/',
     overwrite=True):
     """
     Upload file to Cognite
@@ -256,7 +257,13 @@ def upload_file(
     return file_info
 
 
-def upload_folder(external_id, path, metadata={}, overwrite=False):
+def upload_folder(
+    external_id, 
+    path, 
+    metadata={}, 
+    overwrite=False, 
+    target_folder='/'
+):
     """
     Upload folder content to Cognite. It compresses the folder and uploads it.
     
@@ -264,6 +271,7 @@ def upload_folder(external_id, path, metadata={}, overwrite=False):
         - external_id: external id (should be unique in the CDF project)
         - path: path of local folder where content is stored
         - metadata: dictionary with file metadata
+        - target_folder: path where compressed file should be stored
         - overwrite: if overwrite==False and `external_id` exists => exception
     """
     base_name = os.path.join(path, 'archive')
@@ -272,7 +280,8 @@ def upload_folder(external_id, path, metadata={}, overwrite=False):
         external_id, 
         archive_name, 
         metadata=metadata,
-        overwrite=overwrite
+        overwrite=overwrite,
+        directory=target_folder
     )
     os.remove(archive_name)
     logging.info(f"Folder content uploaded: {file_info=}")
@@ -307,7 +316,7 @@ def log_system_info():
 
 def count_file_versions(
     external_id_prefix, 
-    directory_prefix='/mlops'
+    directory_prefix='/'
 ):
     """
     How many files have the given `external_id_prefix` and `directory_prefix`
@@ -323,83 +332,25 @@ def count_file_versions(
     return result[0]["count"]
 
 
-def upload_new_model_version(model_name, env, folder, metadata):
+def query_file_versions(directory_prefix, external_id_prefix, metadata):
     """
-    Upload a new model version. Files in a folder are archived and stored 
-    with external id `model_name/env/version`, where version is automatically increased. 
+    Find all file versions that match a query. Only versions that were uploaded
+    are considered
 
     Input:
-        -model_name: name of the model 
-        -env: name of the environment ('dev', 'test', 'prod')
-        -folder: path to folder whose content will be uploaded
-        -metadata: dictionary with metadata (it should not contain a 'version'
-        key)
-    
+        -directory_prefix
+        -external_id_prefix
+        -metadata: query to the metadata (dictionary)
     Output:
-        - model metadata (dictionary)
-    """
-
-    filter = f"{model_name}/{env}/"
-    version = count_file_versions(filter) + 1
-    metadata["version"] = version
-    external_id = f"{model_name}/{env}/{version}"
-
-    folder_info = upload_folder(
-        external_id, 
-        folder, 
-        metadata
-    )
-    logging.info(f"Uploaded model with {external_id=} from {folder}")
-    return folder_info
-
-
-def find_model_version(model_name, env, metadata):
-    """
-    Model external id is specified by the model name and the environment
-    (starts with `{model_name}/{env}`), and a query to the metadata. If this is
-    not enough, the latest version is chosen.
-
-    Input:
-        -model_name: name of the model 
-        -env: name of the environment ('dev', 'test', 'prod')
-        -metadata: query to the metadata (dictionary), it can contain a
-        'version' key
+        - list of versions (dataframe)
     """
     client = global_client["files"]
     file_list = client.files.list(
         limit=-1, 
-        directory_prefix='/mlops', 
-        external_id_prefix=f"{model_name}/{env}",
+        directory_prefix=directory_prefix, 
+        external_id_prefix=external_id_prefix,
         metadata=metadata,
         uploaded=True
     ).to_pandas()
 
-    if (n_models := file_list.shape[0]) == 0:
-        message = f"No model found with {model_name=} in {env=} and {metadata}"
-        raise Exception(message)
-    elif n_models > 1:
-        logging.debug(f"Found {n_models} model files. Will choose the latest.")
-    
-    # Get latest in case there are more than one
-    external_id = file_list.loc[file_list.uploadedTime.argmax(), "externalId"]
-    return external_id
-
-
-def download_model_version(model_name, env, folder, metadata={}):
-    """
-    Download a model version to a folder. First the model's external id is
-    found, and then it is downloaded to the chosen folder (creating the folder
-    if necessary).
-
-    Input: 
-        -model_name: name of the model 
-        -env: name of the environment ('dev', 'test', 'prod')
-        -folder: path to folder where the content will be uploaded
-        -metadata: query to the metadata (dictionary)
-    """
-    external_id = find_model_version(model_name, env, metadata)
-    if not os.path.isdir(folder):
-        os.makedirs(folder)
-    download_folder(external_id, folder)
-    logging.info(f"Downloaded model with {external_id=} to {folder}")
-    return external_id
\ No newline at end of file
+    return file_list
