@@ -127,3 +127,9 @@ def run_tests(test_path, path_type='file'):
         raise ValueError("Input should be string or list of strings")
     logging.info(f"Run tests: {test_path}")
     subprocess.check_call(command)
+
+
+def install_requirements(req_file):
+    logging.info(f"Install python requirement file {req_file}")
+    c = ["pip", "install", "--quiet", "-r", req_file]
+    subprocess.check_call(c)
\ No newline at end of file
